@@ -159,11 +159,11 @@ def suspend_file(path):
 	suffix = '.' + get_time_str()
 	path2 = path + suffix
 	
-	if os.exists(path2):
+	if os.path.exists(path2):
 		suffix2 = cool_hash(path2)
 		while True:
 			path3 = path2 + '.' + suffix2
-			if os.exists(path3):
+			if os.path.exists(path3):
 				suffix2 = cool_hash(path3)
 			else:
 				path2 = path3
